function [volume] = fixvolume(volume);

% FIXVOLUME ensures that a source reconstruction, MRI or statistical
% volume is described using a homogenous transformation matrix and that
% the volumes are reshaped to the right dimension.
%
% Furthermore, if the volume contains a seperate inside and outside
% vector with voxel indices, these are transformed into a single boolean 
% inside volume. 

% Copyright (C) 2006, Robert Oostenveld
%
% $Log: fixvolume.m,v $
% Revision 1.1  2006/02/27 16:55:55  roboos
% new function
%

% the volume should have a homogenous transformation matrix instead of xgrid/ygrid/zgrid
volume = grid2transform(volume);

% reformat the inside and outside field to a full volume so that it can be treated just as the other volumes
if isfield(volume, 'inside') && isfield(volume, 'outside')
  tmp = zeros(volume.dim);
  tmp(volume.inside)  = 1;
  tmp(volume.outside) = 0;
  volume.inside = (tmp==1);               % inside is now a logical 3D volume
  volume = rmfield(volume, 'outside');    % outside is not needed any more
end

% reshape each of the volumes that is found into a 3D array
param = parameterselection('all', volume);
for i=1:length(param)
  tmp    = getsubfield(volume, param{i});
  tmp    = reshape(tmp, volume.dim);
  volume = setsubfield(volume, param{i}, tmp);
end
